<?php

/**
 * @copyright 	Copyright (c) 2009-2017 Ryan Demmer. All rights reserved
 * @license   	GNU/GPL 2 or later - http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * JCE is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses
 */
defined('_WF_EXT') or die('RESTRICTED');

class JoomlalinksGMapFP extends JObject
{
    public $_option = 'com_gmapfp';

    /**
     * Constructor activating the default information of the class.
     */
    public function __construct($options = array())
    {
    }

    public static function getInstance()
    {
        static $instance;

        if (!is_object($instance)) {
            $instance = new self();
        }

        return $instance;
    }

    public function getOption()
    {
        return $this->_option;
    }

    public function getList()
    {
        $wf = WFEditorPlugin::getInstance();

        if ($wf->checkAccess('links.joomlalinks.gmapfp', 1)) {
            return '<li data-id="index.php?option=com_gmapfp" class="folder gmapfp nolink"><div class="uk-tree-row"><a href="#"><span class="uk-tree-icon"></span><span class="uk-tree-text">'.WFText::_('WF_LINKS_JOOMLALINKS_GMAPFP').'</span></a></div></li>';
        }
    }

    public function getLinks($args)
    {
        $wf = WFEditorPlugin::getInstance();

        require_once JPATH_SITE.'/components/com_gmapfp/helpers/route.php';

        $items = array();
        $language = '';

		$statics = self::_getUncategorized();

		foreach ($statics as $static) {
			// language
			if (isset($static->language)) {
				$language = $static->language;
			}

			$id = GMapFPHelperRoute::getArticleRoute($static->id, 0, $language);

			// $id = self::route($id);

			$items[] = array(
				'id' => $id,
				'name' => $static->title.' / '.$static->alias,
				'class' => 'file',
			);

			$anchors = self::getAnchors($statics->content);

			foreach ($anchors as $anchor) {
				$items[] = array(
					'id' => $id.'#'.$anchor,
					'name' => '#'.$anchor,
					'class' => 'file anchor',
				);
			}
		}

        return $items;
    }

    private function _getMenuLink($url)
    {
        $wf = WFEditorPlugin::getInstance();

        // resolve the url from the menu link
        if ($wf->getParam('links.joomlalinks.article_resolve_alias', 1) == 1) {
            // get itemid
            preg_match('#Itemid=([\d]+)#', $url, $matches);
            // get link from menu
            if (count($matches) > 1) {
                $menu = JTable::getInstance('menu');
                $menu->load($matches[1]);

                if ($menu->link) {
                    return $menu->link.'&Itemid='.$menu->id;
                }
            }
        }

        return $url;
    }

    private function _getUncategorized()
    {
        $db = JFactory::getDBO();
        $user = JFactory::getUser();
		$groups	= implode(',', $user->getAuthorisedViewLevels());

        $query = 'SELECT id, nom as title, alias, access, introtext AS content, language'
                .' FROM #__gmapfp'
                .' WHERE published = 1'
                .' AND (access IN ('.$groups.') or (access = ""))'
                .' ORDER BY title';

        $db->setQuery($query, 0);

        return $db->loadObjectList();
    }

    private function getItemId($url)
    {
    }

    private static function getAnchors($content)
    {
        preg_match_all('#<a([^>]+)(name|id)="([a-z]+[\w\-\:\.]*)"([^>]*)>#i', $content, $matches, PREG_SET_ORDER);

        $anchors = array();

        if (!empty($matches)) {
            foreach ($matches as $match) {
                if (strpos($match[0], 'href') === false) {
                    $anchors[] = $match[3];
                }
            }
        }

        return $anchors;
    }

    private static function route($url)
    {
        $wf = WFEditorPlugin::getInstance();

        if ($wf->getParam('links.joomlalinks.sef_url', 0)) {
            // $url = WFLinkExtension::route($url);
        }

        return $url;
    }
}
